Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/httpx/__init__.py | 15 | 0 | 0 | 100%
src/httpx/_client.py | 73 | 4 | 0 | 95%
src/httpx/_content.py | 194 | 4 | 0 | 98%
src/httpx/_headers.py | 74 | 5 | 0 | 93%
src/httpx/_network.py | 79 | 4 | 0 | 95%
src/httpx/_pool.py | 206 | 11 | 0 | 95%
src/httpx/_request.py | 35 | 1 | 0 | 97%
src/httpx/_response.py | 34 | 1 | 0 | 97%
src/httpx/_server.py | 153 | 17 | 0 | 89%
src/httpx/_streams.py | 76 | 3 | 0 | 96%
src/httpx/_urlencode.py | 44 | 0 | 0 | 100%
src/httpx/_urlparse.py | 191 | 53 | 0 | 72%
src/httpx/_urls.py | 170 | 27 | 0 | 84%
Total | 1344 | 130 | 0 | 90%

No items found using the specified filter.